@@ -50,11 +50,11 @@ nibe_schema = Schema(
             Optional("options", default=None): Any(None, dict),
         },
         Required("model"): heatpump_model,
+        Optional("word_swap", default=True): bool,
         Optional("poll"): {
             Optional("interval", default=60): All(int, Range(min=5, max=60 * 60 * 24)),
             Optional("coils"): [str, int],
-        },
-        Optional("retry_delays", default=[0.0, 0.5]): [float],
+        }
     }
 )
 
